@@ -1,6 +1,6 @@
 package App::optex::up;
 
-our $VERSION = "1.01";
+our $VERSION = "1.02";
 
 =encoding utf-8
 
@@ -26,6 +26,9 @@ refers to printing multiple pages on a single sheet.
 The module automatically calculates the number of columns based on the
 terminal width divided by the pane width (default 85 characters).
 
+Both stdout and stderr are merged and passed through the filter, so
+error messages are also displayed in the multi-column paged output.
+
 The pager command is taken from the C<$PAGER> environment variable if
 set, otherwise defaults to C<less>.  When using C<less>, C<-F +Gg>
 options are automatically appended.  C<-F> causes C<less> to exit
@@ -39,12 +42,6 @@ Module options must be specified before C<--> separator.
 
 =over 4
 
-=item B<--grid>=I<CxR>, B<-G> I<CxR>
-
-Set the grid layout.  For example, C<--grid=2x3> or C<--grid=2,3>
-creates a 2-column, 3-row layout (6-up).  This is equivalent to
-C<-C2 -R3>.
-
 =item B<--pane>=I<N>, B<-C> I<N>
 
 Set the number of columns (panes) directly.
@@ -54,6 +51,12 @@ Set the number of columns (panes) directly.
 Set the number of rows.  The page height is calculated by dividing
 the terminal height by this value.
 
+=item B<--grid>=I<CxR>, B<-G> I<CxR>
+
+Set the grid layout.  For example, C<--grid=2x3> or C<--grid=2,3>
+creates a 2-column, 3-row layout (6-up).  This is equivalent to
+C<-C2 -R3>.
+
 =item B<--height>=I<N>
 
 Set the page height directly in lines.
@@ -223,7 +226,7 @@ sub finalize {
     $pager .= ' -F +Gg' if $pager =~ /\bless\b/;
 
     # Build default ansicolumn options
-    my @ac_opts = ("--bs=$border_style", "--cm=BORDER=L13", "-DBP", "-C$cols");
+    my @ac_opts = ("-w$term_width", "--bs=$border_style", "--cm=BORDER=L13", "-DBP", "-C$cols");
     push @ac_opts, "--height=$height" if defined $height;
     push @ac_opts, "--ls=$line_style" if defined $line_style;
     push @ac_opts, "--no-page" if $config->{fold};
@@ -235,13 +238,13 @@ sub finalize {
         if ($config->{'no-pager'} || $pager eq '') {
             return;  # No filter needed
         }
-        $mod->setopt(default => "-Mutil::filter --of='$pager'");
+        $mod->setopt(default => "-Mutil::filter --of='$pager' --ef='>&1'");
         return;
     }
 
     my $column = join ' ', 'ansicolumn', @ac_opts;
     my $filter = ($config->{'no-pager'} || $pager eq '') ? $column : "$column|$pager";
-    $mod->setopt(default => "-Mutil::filter --of='$filter'");
+    $mod->setopt(default => "-Mutil::filter --of='$filter' --ef='>&1'");
 }
 
 1;
